@@ -10,7 +10,7 @@ from .views.feed import ArticleFeed, ChannelFeed
 
 urlpatterns = patterns(
     '',
-    url(r'^$', cache_page(60 * 2)(PostList.as_view()), name='home'),
+    url(r'^$', PostList.as_view(), name='home'),
     url(r'^(rss|feed)$', cache_page(60 * 2)(ArticleFeed()), name='feed'),
     url(r'^search/', Search(), name='search'),
 
@@ -19,9 +19,9 @@ urlpatterns = patterns(
         cache_page(60 * 2)(ChannelFeed(model='Album')),
         name='album_feed'),
     url(r'^album/(?P<channel__long_slug>[\w//-]+)/(?P<slug>[\w-]+)$',
-        cache_page(60 * 15)(AlbumDetail.as_view()), name='album_open'),
+        AlbumDetail.as_view(), name='album_open'),
     url(r'^album/(?P<channel__long_slug>[\w\b//-]+)/$',
-        cache_page(60 * 2)(AlbumList.as_view()), name='album_channel'),
+        AlbumList.as_view(), name='album_channel'),
 
     # TAGs
     url(r'^tag/(?P<tag>[\w//-]+)$',
@@ -31,7 +31,7 @@ urlpatterns = patterns(
     url(r'^(?P<long_slug>[\w\b//-]+)/(rss|feed)$',
         cache_page(60 * 2)(ChannelFeed(model='Post')), name='channel_feed'),
     url(r'^(?P<channel__long_slug>[\w//-]+)/(?P<slug>[\w-]+)$',
-        cache_page(60 * 15)(PostDetail.as_view()), name='open'),
+        PostDetail.as_view(), name='open'),
     url(r'^(?P<channel__long_slug>[\w\b//-]+)/$',
-        cache_page(60 * 2)(PostList.as_view()), name='channel'),
+        PostList.as_view(), name='channel'),
 )
