@@ -4,10 +4,11 @@ from django.contrib.auth import get_user_model
 from django.utils.translation import ugettext_lazy as _
 
 from .models import Channel, ChannelConfig
-from .utils import generate_long_slug
 from opps.core.admin import PublishableAdmin
+from opps.core.admin import apply_opps_rules
 
 
+@apply_opps_rules('channels')
 class ChannelAdmin(PublishableAdmin):
     prepopulated_fields = {"slug": ("name",)}
     list_display = ['name', 'parent', 'site', 'date_available', 'homepage',
@@ -20,15 +21,17 @@ class ChannelAdmin(PublishableAdmin):
     fieldsets = (
         (_(u'Identification'), {
             'fields': ('site', 'parent', 'name', 'slug', 'description',
-                       'order', 'show_in_menu', 'homepage',)}),
+                       'order', 'show_in_menu', 'homepage', 'group')}),
         (_(u'Publication'), {
             'classes': ('extrapretty'),
             'fields': ('published', 'date_available')}),
     )
 
     def save_model(self, request, obj, form, change):
-        obj.long_slug = generate_long_slug(obj.parent, obj.slug,
-                                           obj.site.domain)
+        long_slug = u"{}".format(obj.slug)
+        if obj.parent:
+            long_slug = u"{}/{}".format(obj.parent.slug, obj.slug)
+        obj.long_slug = long_slug
 
         super(ChannelAdmin, self).save_model(request, obj, form, change)
 
